@@ -29,6 +29,12 @@ has 'builder' => (
     default => 'Deb',
 );
 
+has 'downloader' => (
+    is      => 'rw',
+    isa     => 'Str',
+    default => 'CPANPLUS',
+);
+
 has 'conf' => (
     is  => 'rw',
     isa => 'Str',
@@ -45,6 +51,12 @@ has 'modulelist' => (
     isa => 'Str',
 );
 
+has 'verbose' => (
+    is      => 'rw',
+    isa     => 'Bool',
+    default => 0,
+);
+
 sub run {
     my $self = shift;
     if ( $self->help ) {
@@ -52,15 +64,17 @@ sub run {
     }
     die 'conf is required param' unless $self->conf;
 
-    unless( $self->builder eq "Deb" || $self->builder eq "RPM") {
+    unless ( $self->builder eq "Deb" || $self->builder eq "RPM" ) {
         die 'builder option value must be Deb or RPM';
     }
 
     my $packager = CPAN::Packager->new(
         builder      => $self->builder,
+        downloader   => $self->downloader,
         conf         => $self->conf,
         always_build => $self->always_build,
         dry_run      => $self->dry_run,
+        verbose      => $self->verbose,
     );
 
     if ( $self->modulelist ) {
